---
title: <span class="badge object-type-scalar"></span> PartsPerMillion
---
# <span class="badge object-type-scalar"></span> PartsPerMillion

Concentration: parts-per-million (ppm)

## Definition

```python
# Concentration: parts-per-million (ppm)
PartsPerMillion: typing.Literal["ppm"] = "ppm"
```
